/* eslint-disable @typescript-eslint/no-unused-vars */
import { ErrorListener } from 'antlr4';
import { ParseError } from '../Errors.js';
import { Point } from './Location.js';
/**
 * ANTLR Error Listener that immediately throws on error. This is used so that
 * ANTLR doesn't attempt any error recovery during lexing/parsing and fails early.
 */
class ThrowingErrorListener extends ErrorListener {
    syntaxError(recognizer, offendingSymbol, line, charPositionInLine, message, e) {
        const capitalisedMessage = message.charAt(0).toUpperCase() + message.slice(1);
        throw new ParseError(capitalisedMessage, new Point(line, charPositionInLine));
    }
}
ThrowingErrorListener.INSTANCE = new ThrowingErrorListener();
export default ThrowingErrorListener;
//# sourceMappingURL=ThrowingErrorListener.js.map